You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@sling.apache.org by ro...@apache.org on 2022/03/18 15:56:56 UTC

[sling-tooling-release] 01/02: SLING-11163 - Update generate_javadoc_for_release.sh to work on the feature model

This is an automated email from the ASF dual-hosted git repository.

rombert pushed a commit to branch issue/SLING-11163
in repository https://gitbox.apache.org/repos/asf/sling-tooling-release.git

commit 1df6df4063ffc468c4cce8e6e7cb8678335d7ce0
Author: Robert Munteanu <ro...@apache.org>
AuthorDate: Fri Mar 18 16:43:18 2022 +0100

    SLING-11163 - Update generate_javadoc_for_release.sh to work on the feature model
    
    Read bundle information from the feature model
---
 generate_javadoc_for_release.sh | 14 +++++++-------
 1 file changed, 7 insertions(+), 7 deletions(-)

diff --git a/generate_javadoc_for_release.sh b/generate_javadoc_for_release.sh
index 445926e..87388bc 100755
--- a/generate_javadoc_for_release.sh
+++ b/generate_javadoc_for_release.sh
@@ -1,6 +1,6 @@
 #!/bin/bash -e
 
-VERSION=11
+VERSION=12
 WORKDIR=out
 ALLOW_SNAPSHOT=0
 
@@ -10,15 +10,15 @@ if [ ! -d $WORKDIR ] ; then
 fi
 
 # get bundle list
-if [ -f $WORKDIR/slingfeature.txt ] ; then
-    echo "slingfeature.txt already present, not downloading";
+if [ -f $WORKDIR/feature.json ] ; then
+    echo "feature.json already present, not downloading";
 else
-    echo "Downloading bundle list for Sling $VERSION"
-    wget https://repo1.maven.org/maven2/org/apache/sling/org.apache.sling.starter/$VERSION/org.apache.sling.starter-$VERSION-slingfeature.txt -O $WORKDIR/slingfeature.txt
+    echo "Downloading bundle list for Sling $VERSION (oak-tar variant)"
+    wget  https://repo1.maven.org/maven2/org/apache/sling/org.apache.sling.starter/$VERSION/org.apache.sling.starter-$VERSION-oak_tar.slingosgifeature -O $WORKDIR/feature.json
 fi
 
-# extract <artifactId>-<version> from slingfeature.txt
-artifacts=$(awk -F '/' '/org.apache.sling\// { print $2 ":" $3 }' < $WORKDIR/slingfeature.txt)
+# extract <artifactId>-<version> from feature file
+artifacts=$(cat $WORKDIR/feature.json | jq -r '.bundles[].id | select(startswith("org.apache.sling"))' | awk -F ':' '{ print $2 ":" $3 }')
 
 # add additional artifacts which are not part of the launchpad
 # https://issues.apache.org/jira/browse/SLING-6766